import QtQuick
import QtQuick.Controls
import QtQuick.Layouts

import "../components"
import "view"

import Artix.Core
import Artix.Gui
import Artix.Models
import Artix.Handlers

/**
 * @brief Форма внесения/выема денежных средств
 */
BasicView {
    id: root

    contentItem: RowLayout {
        spacing: 0
        Rectangle {
            Layout.fillWidth: true
            Layout.fillHeight: true
            color: Style.parameter("color.modalBackground")
            ColumnLayout {
                anchors {
                    top: parent.top; left: parent.left
                    leftMargin: 24; topMargin: 16
                }
                BasicLabel {
                    Style.class: "cashManagementTitle"
                    Tr {
                        tr: Session.document.type === DocumentType.MoneyIn
                            ? Utils.makeTr("cashManagementMoneyIn", "Внесение денег №%1")
                            : Utils.makeTr("cashManagementMoneyOut", "Выем денег №%1")
                        args: [ Session.document.num ]
                    }
                }
                Item { Layout.preferredHeight: 32 }
                BasicLabel {
                    Style.class: "cashManagementTypeTitle"
                    Tr { tr: Utils.makeTr("cashManagementValutLabel", "Тип оплаты") }
                }
                Item { Layout.preferredHeight: 4 }
                BasicLabel {
                    Style.class: "cashManagementTypeValue"
                    text: SystemInfo.cashValutName()
                }
                Item { Layout.preferredHeight: 24 }
                BasicLabel {
                    Style.class: "cashManagementSumTitle"
                    Tr { tr: Utils.makeTr("cashManagementTotalLabel", "Итого") }
                }
                Item { Layout.preferredHeight: 4 }
                BasicLabel {
                    Style.class: "cashManagementSumValue"
                    text: Utils.formatMoneyItem(Session.document.sumb)
                }
            }
        }
        // Цифровая клавиатура
        Item {
            Layout.fillHeight: true
            Layout.preferredWidth: 304
            TopPanel {
                anchors { left: parent.left; top: parent.top; right: parent.right }
                anchors.leftMargin: 24
                hideUserName: true
            }
            ColumnLayout {
                anchors { left: parent.left; right: parent.right; bottom: parent.bottom; margins: 24 }
                spacing: 0
                BasicTextField {
                    id: inputField
                    Style.class: "cashManagementInput"
                    Layout.fillWidth: true
                    Layout.preferredHeight: 64
                    padding: 12
                    onFocusChanged: focus = true
                    hideCursor: true
                    fixedCursorPosition: true
                    validator: DoubleValidator { bottom: 0.0; decimals: 2 }
                    BasicLabel {
                        Style.class: "cashManagementInputPlaceholder"
                        anchors.left: parent.left
                        anchors.bottom: parent.bottom
                        anchors.margins: 12
                        visible: !inputField.text.length
                        Tr { code: "cashManagementInputPlaceholder"; defaultMessage: "Сумма" }
                    }
                }
                Item { Layout.preferredHeight: 24 }
                InlineKeyboard {
                    Layout.fillWidth: true
                    Layout.preferredHeight: 296
                    layoutType: "digits"
                }
                Item { Layout.preferredHeight: 16 }
                BasicButton {
                    Style.class: "cashManagementDrawer"
                    Layout.fillWidth: true
                    Layout.preferredHeight: 68
                    textLayout { fillWidth: true; fillHeight: true }
                    topPadding: 0; bottomPadding: 0
                    verticalAlignment: Qt.AlignVCenter
                    onClicked: handler.cashDrawer()
                    Tr { code: "cashManagementFormCashDrawerButton"; defaultMessage: "Открыть денежный ящик" }
                }
                Item { Layout.preferredHeight: 8 }
                BasicButton {
                    Style.class: "cashManagementCancel"
                    Layout.fillWidth: true
                    Layout.preferredHeight: 68
                    onClicked: handler.cancel()
                    Tr { code: "cashManagementFormCancelButton"; defaultMessage: "Назад" }
                }
                Item { Layout.preferredHeight: 8 }
                BasicButton {
                    Style.class: "cashManagementOk"
                    Layout.fillWidth: true
                    Layout.preferredHeight: 68
                    iconLayout.alignment: Qt.AlignTop | Qt.AlignRight
                    icon: inputField.text.length ? "" : Style.parameter("icon.actionPanel.arrow")
                    onClicked: accept()
                    Tr {
                        tr: {
                            if (!inputField.text.length)
                                return Utils.makeTr("cashManagementFormTotalButton", "Итог")
                            if (Session.document.type === DocumentType.MoneyIn)
                                return Utils.makeTr("cashManagementMoneyIn", "Внести")
                            else
                                return Utils.makeTr("cashManagementMoneyOut", "Изъять")
                        }
                    }
                }
            }
        }
    }

    footer: BottomPanel {}

    CashManagementHandler { id: handler }

    // Фильтр и коннектор для работы с клавиатурой
    EventFilterConnector {
        receiver: inputField
        filter: DialogEventFilter {
            onOk: accept()
            onCancel: esc()
        }
    }

    function setFocus() { inputField.forceActiveFocus() }

    function esc() {
        if (inputField.text.length > 0)
            inputField.text = ""
        else
            handler.cancel()
    }

    function accept() {
        if (inputField.text.length > 0) {
            let amount = parseFloat(inputField.text)
            inputField.text = ""
            handler.inputAmount(amount)
        } else {
            handler.total()
        }
    }
}
