import QtQuick
import QtQuick.Controls
import QtQuick.Layouts

import "../../components"

import Artix.Core
import Artix.Gui

/**
 * @brief Навигация по списку для резистентных мониторов
 */
Item {
    id: root
    required property ListView target

    // Тень
    Rectangle {
        anchors.bottom: parent.top
        width: parent.width
        height: 5
        gradient: Gradient {
            orientation: Gradient.Vertical
            GradientStop { position: 0.0; color: "transparent" }
            GradientStop { position: 1.0; color: Style.parameter("color.shadow") }
        }
        opacity: 0.3
    }

    // Кнопки
    RowLayout {
        anchors.right: parent.right
        anchors.margins: 24
        anchors.verticalCenter: parent.verticalCenter
        spacing: 16
        BasicButton {
            Layout.preferredWidth: 68
            Layout.preferredHeight: 68
            Style.class: "listNavigationDown"
            icon: Style.parameter("icon.authArrowDown")
            onClicked: root.scrollDown()
        }
        BasicButton {
            Layout.preferredWidth: 68
            Layout.preferredHeight: 68
            Style.class: "listNavigationUp"
            icon: Style.parameter("icon.authArrowUp")
            onClicked: root.scrollUp()
        }
    }

    function getVisibleIndexRange() {
            let center_x = target.x + target.width / 2
            return [target.indexAt( center_x, target.y + target.contentY),
                    target.indexAt( center_x, target.y + target.contentY + target.height)]
        }
    function scrollUp() {
        let firstIndex = getVisibleIndexRange()[0]
        if (firstIndex === 0)
            return
        target.positionViewAtIndex(firstIndex - 1, ListView.Contain)
        target.ScrollBar.vertical.active = true
    }
    function scrollDown() {
        let lastIndex = getVisibleIndexRange()[1]
        if (lastIndex === target.count - 1)
            return
        target.positionViewAtIndex(lastIndex + 1, ListView.Contain)
        target.ScrollBar.vertical.active = true
    }
}
