import QtQuick
import QtQuick.Controls
import QtQuick.Layouts

import "../../components"

import Artix.Core
import Artix.Gui
import Artix.Models

/**
 * @brief Верхняя панель
 * @param hideUserName скрыть имя и должность пользователя
 */
Rectangle {
    property bool hideUserName: false

    color: "transparent"
    height: 72

    ColumnLayout {
        anchors.left: parent.left
        anchors.verticalCenter: parent.verticalCenter
        spacing: 4
        visible: !hideUserName
        BasicLabel {
            text: Session.user.name
            Style.class: "topPanelUser"
        }
        BasicLabel {
            text: Session.user.rank
            Style.class: "topPanelRank"
        }
    }
    BasicButton {
        id: sideMenuButton
        anchors.right: parent.right
        anchors.rightMargin: 10
        anchors.verticalCenter: parent.verticalCenter
        Style.class: "sideMenuOpen"
        width: 56
        height: 56
        radius: 28
        icon: Style.parameter("icon.topPanel.sideMenu")
        onClicked: {
            Window.window.sidePanelRef.createMenu()
            Window.window.sidePanelRef.open()
        }
    }
    RowLayout {
        id: iconsView
        anchors.right: sideMenuButton.left
        anchors.rightMargin: 4
        anchors.verticalCenter: parent.verticalCenter
        layoutDirection: Qt.RightToLeft
        spacing: 4
        Repeater {
            model: SystemIndicatorModel {}
            delegate: Image {
                Layout.alignment: Qt.AlignVCenter
                Layout.preferredHeight: 24
                Layout.preferredWidth: 24
                source: Style.parameter(icon, icon)
                fillMode: Image.PreserveAspectFit
            }
        }
        RowLayout {
            id: upload
            spacing: 2
            visible: false
            Image {
                Layout.alignment: Qt.AlignVCenter
                source: Style.parameter("icon.topPanel.upload")
            }
            BasicLabel {
                Layout.alignment: Qt.AlignVCenter
                id: uploadPercent
                Style.class: "topPanelUpload"
                text: "100%"
            }
        }
        // Иконка наличия оповещений
        Image {
            id: notificationIcon
            Layout.preferredHeight: 24
            Layout.preferredWidth: 24
            property int infoCount: NotificationStorage.count(Notification.Info)
            property int errorCount: NotificationStorage.count(Notification.Error | Notification.Mode)
            readonly property string infoIcon: Style.parameter("icon.topPanel.notificationInfo")
            readonly property string errorIcon: Style.parameter("icon.topPanel.notificationError")
            source: {
                if (errorCount)
                    return errorIcon
                return infoIcon
            }
            visible: infoCount || errorCount
            Connections {
                target: NotificationStorage
                function onAdded() {
                    notificationIcon.infoCount = NotificationStorage.count(Notification.Info)
                    notificationIcon.errorCount = NotificationStorage.count(Notification.Error | Notification.Mode)
                }
                function onRemoved() {
                    notificationIcon.infoCount = NotificationStorage.count(Notification.Info)
                    notificationIcon.errorCount = NotificationStorage.count(Notification.Error | Notification.Mode)
                }
                function onReplaced() {
                    notificationIcon.infoCount = NotificationStorage.count(Notification.Info)
                    notificationIcon.errorCount = NotificationStorage.count(Notification.Error | Notification.Mode)
                }
            }
        }
    }
    MouseArea {
        anchors.fill: iconsView
        onClicked: notificationArea.open()
    }

    NotificationArea {
        id: notificationArea
        width: parent.width
    }

    Connections {
        target: UploadWatcher
        function onActivated(state) {
            upload.visible = state
        }
        function onProgressChanged(progress) {
            uploadPercent.text = progress + "%"
        }
    }

    function open() { notificationArea.open() }
}
