import QtQuick
import QtQuick.Controls
import QtQuick.Layouts

import "../../../components"
import "../"

import Artix.Core
import Artix.Gui

/**
 * @brief Панель оплаты наличными
 */
ColumnLayout {
    id: root
    spacing: 16

    signal back()
    signal stornoAll()
    signal commit(var action, var args)
    property var action
    readonly property TextField inputField: inputField

    // Поле ввода
    BasicTextField {
        id: inputField

        Layout.fillWidth: true
        Layout.preferredHeight: 64
        Style.class: "documentSubtotalInput"
        padding: 12
        verticalAlignment: Text.AlignVCenter
        horizontalAlignment: Text.AlignRight
        hideCursor: true
        fixedCursorPosition: true
        validator: DoubleValidator {
            notation: DoubleValidator.StandardNotation
            bottom: 0.0
            decimals: 2
        }
    }
    GridLayout {
        id: cashButtons
        rows: 2
        columns: 4
        rowSpacing: 8
        columnSpacing: 8
        Repeater {
            model: ListModel {
                ListElement { row: 0; column: 0; value: 100 }
                ListElement { row: 0; column: 1; value: 200 }
                ListElement { row: 0; column: 2; value: 500 }
                ListElement { row: 0; column: 3; value: 1000 }
                ListElement { row: 1; column: 0; value: 2000 }
                ListElement { row: 1; column: 1; value: 5000 }
            }
            delegate: GroupBox {
                Layout.preferredWidth: 124
                Layout.preferredHeight: 64
                Layout.row: row
                Layout.column: column
                Style.class: "cashButtonDelegate"
                property real borderWidth: Style.background.border.width
                Image {
                    anchors.right: parent.right
                    anchors.bottom: parent.bottom
                    anchors.margins: parent.borderWidth
                    height: parent.height - parent.borderWidth * 2
                    fillMode: Image.PreserveAspectFit
                    source: down ? Style.parameter("icon.subtotal.rubPressed")
                                 : Style.parameter("icon.subtotal.rubNormal")
                }
                BasicLabel {
                    anchors.margins: 12
                    anchors.left: parent.left
                    anchors.bottom: parent.bottom
                    Style.class: "cashButtonDelegate"
                    text: value
                }
                onClicked: {
                    if (inputField.selectedText.length > 0)
                        inputField.text = "0.0"
                    inputField.text = parseFloat(inputField.text) + value
                }
            }
        }
    }
    // Клавиатура и панель действий
    GridLayout {
        rowSpacing: 8
        columnSpacing: 8
        columns: 2
        rows: 3

        BasicButton {
            Style.class: "actionPanelDelegate24px600"
            Layout.preferredWidth: 256
            Layout.preferredHeight: 70
            Layout.row: 0
            Layout.column: 1

            textLayout {
                fillWidth: true
                fillHeight: true
            }
            iconLayout {
                alignment: Qt.AlignRight | Qt.AlignTop
                preferredWidth: 32
                preferredHeight: 32
            }
            verticalAlignment: Text.AlignBottom
            Tr { code: "actionPanelButtonStorno"; defaultMessage: "Отмена чека" }
            onClicked: root.stornoAll()
        }
        BasicButton {
            Style.class: "actionPanelDelegate24px600"
            Layout.preferredWidth: 256
            Layout.preferredHeight: 70
            Layout.row: 1
            Layout.column: 1

            textLayout {
                fillWidth: true
                fillHeight: true
            }
            iconLayout {
                alignment: Qt.AlignRight | Qt.AlignTop
                preferredWidth: 32
                preferredHeight: 32
            }
            verticalAlignment: Text.AlignBottom
            Tr { code: "actionPanelButtonBack"; defaultMessage: "Назад" }
            onClicked: root.back()
        }
        BasicButton {
            Style.class: "actionPanelDelegateContinue"
            Layout.preferredWidth: 256
            Layout.preferredHeight: 147
            Layout.row: 2
            Layout.column: 1
            Layout.columnSpan: 2

            textLayout {
                fillWidth: true
                fillHeight: true
            }
            iconLayout {
                alignment: Qt.AlignRight | Qt.AlignTop
                preferredWidth: 32
                preferredHeight: 32
            }
            verticalAlignment: Text.AlignBottom
            icon: Style.parameter("icon.actionPanel.arrow")
            Tr { code: "actionPanelButtonAdd"; defaultMessage: "Добавить" }
            onClicked: {
                let args = {}
                if (inputField.text.length > 0)
                    args["amount"] = inputField.text
                root.commit(root.action, args)
            }
        }
        InlineKeyboard {
            Style.class: "actionPanelDelegate"
            Layout.fillHeight: true
            Layout.preferredWidth: 256
            Layout.row: 0
            Layout.rowSpan: 3
            Layout.column: 0
            layoutType: "digits"
        }
    }
}
